# coding: utf-8
from enum import Enum, unique


@unique
class RefundType(Enum):
    
    MERCHANT_INITIATED_ONLINE = "MERCHANT_INITIATED_ONLINE"
    MERCHANT_INITIATED_OFFLINE = "MERCHANT_INITIATED_OFFLINE"
    CUSTOMER_INITIATED_AUTOMATIC = "CUSTOMER_INITIATED_AUTOMATIC"
    CUSTOMER_INITIATED_MANUAL = "CUSTOMER_INITIATED_MANUAL"

